@@ -1,19 +1,13 @@
 import os
 from os import path
-import json
 import pickle
-import operator as op
 import warnings
 from ase import constraints
 import numpy as np
-from ase.atoms import Atoms
 from ase.calculators.calculator import kpts2ndarray, kpts2sizeandoffsets
 from ase.constraints import FixAtoms, FixCartesian
 from ase.data import chemical_symbols, atomic_numbers
 from ase.io.espresso import read_espresso_in, construct_namelist, grep_valence, SSSP_VALENCE, read_fortran_namelist
-from ase.units import create_units
-from pprint import pprint
-from xespresso.utils import check_type
 
 
 def write_espresso_in(filename, atoms, input_data={}, pseudopotentials=None,
@@ -25,7 +19,7 @@ def write_espresso_in(filename, atoms, input_data={}, pseudopotentials=None,
     Modified the read_espresso_in function from ase.io.espresso
     Parameters:
         Please have a look at the ase.io.espresso module in ASE
-    
+
     Implemented:
 
     - support parameters with ntyp
@@ -40,9 +34,11 @@ def write_espresso_in(filename, atoms, input_data={}, pseudopotentials=None,
     # Construct input file into this
     pwi = []
     # atomic_species
-    atomic_species_str, species_info, total_valence = build_atomic_species_str(atoms, input_parameters, pseudopotentials)
+    atomic_species_str, species_info, total_valence = build_atomic_species_str(
+        atoms, input_parameters, pseudopotentials)
     # sections
-    section_str, input_parameters = build_section_str(atoms, species_info, input_data, input_parameters)
+    section_str, input_parameters = build_section_str(
+        atoms, species_info, input_data, input_parameters)
     pwi.extend(section_str)
     # Pseudopotentials
     pwi.extend(atomic_species_str)
@@ -60,6 +56,7 @@ def write_espresso_in(filename, atoms, input_data={}, pseudopotentials=None,
     # return section_str, atomic_species_str, kpts_str, cell_str, atomic_positions_str
     return engine_str
 
+
 def build_section_str(atoms, species_info, input_data, input_parameters):
     '''
     '''
@@ -74,12 +71,13 @@ def build_section_str(atoms, species_info, input_data, input_parameters):
         for key, value in input_data['INPUT_NTYP'].items():
             for species in value:
                 if species in species_info:
-                    mag_str = '{0}({1})'.format(key, species_info[species]['index'])
+                    mag_str = '{0}({1})'.format(
+                        key, species_info[species]['index'])
                     input_parameters['system'][mag_str] = value[species]
     if 'hubbard_v' in input_data:
         for key, value in input_data['hubbard_v'].items():
-                    mag_str = 'Hubbard_V{0}'.format(key)
-                    input_parameters['system'][mag_str] = value
+            mag_str = 'Hubbard_V{0}'.format(key)
+            input_parameters['system'][mag_str] = value
     # Use cell as given or fit to a specific ibrav
     if 'ibrav' in input_parameters['system']:
         ibrav = input_parameters['system']['ibrav']
@@ -110,6 +108,7 @@ def build_section_str(atoms, species_info, input_data, input_parameters):
     section_str.append('\n')
     return section_str, input_parameters
 
+
 def build_atomic_species_str(atoms, input_parameters, pseudopotentials):
     '''
     '''
@@ -126,7 +125,8 @@ def build_atomic_species_str(atoms, input_parameters, pseudopotentials):
     # Species info holds the information on the pseudopotential and
     # associated for each element
     if 'species' not in atoms.arrays:
-        atoms.new_array('species', np.array(atoms.get_chemical_symbols(), dtype = 'U20'))
+        atoms.new_array('species', np.array(
+            atoms.get_chemical_symbols(), dtype='U20'))
     if pseudopotentials is None:
         pseudopotentials = {}
     species_info = {}
@@ -152,7 +152,7 @@ def build_atomic_species_str(atoms, input_parameters, pseudopotentials):
                 valence = grep_valence(path.join(pseudo_dir, pseudo))
                 break
         else:  # not found in a file
-            valence = SSSP_VALENCE[atomic_numbers[species_info[species]['element']]] 
+            valence = SSSP_VALENCE[atomic_numbers[species_info[species]['element']]]
         species_info[species]['pseudo'] = pseudo,
         species_info[species]['valence'] = valence
         total_valence += valence*species_info[species]['count']
@@ -162,7 +162,7 @@ def build_atomic_species_str(atoms, input_parameters, pseudopotentials):
                 pseudo=pseudo))
     atomic_species_str.append('\n')
     return atomic_species_str, species_info, total_valence
-              
+
 
 def build_cell_str(atoms, input_parameters):
     '''
@@ -171,11 +171,13 @@ def build_cell_str(atoms, input_parameters):
     if input_parameters['SYSTEM']['ibrav'] == 0:
         cell_str = ['CELL_PARAMETERS angstrom\n']
         cell_str.append('{cell[0][0]:.14f} {cell[0][1]:.14f} {cell[0][2]:.14f}\n'
-                   '{cell[1][0]:.14f} {cell[1][1]:.14f} {cell[1][2]:.14f}\n'
-                   '{cell[2][0]:.14f} {cell[2][1]:.14f} {cell[2][2]:.14f}\n'
-                   ''.format(cell=atoms.cell))
+                        '{cell[1][0]:.14f} {cell[1][1]:.14f} {cell[1][2]:.14f}\n'
+                        '{cell[2][0]:.14f} {cell[2][1]:.14f} {cell[2][2]:.14f}\n'
+                        ''.format(cell=atoms.cell))
         cell_str.append('\n')
     return cell_str
+
+
 def build_kpts_str(atoms, kspacing, kpts, koffset):
     '''
     '''
@@ -206,7 +208,8 @@ def build_kpts_str(atoms, kspacing, kpts, koffset):
         kgrid = kpts2ndarray(kgrid, atoms=atoms)
         kpts_str.append('%s\n' % len(kgrid))
         for k in kgrid:
-            kpts_str.append('{k[0]:.14f} {k[1]:.14f} {k[2]:.14f} 0\n'.format(k=k))
+            kpts_str.append(
+                '{k[0]:.14f} {k[1]:.14f} {k[2]:.14f} 0\n'.format(k=k))
         kpts_str.append('\n')
     elif isinstance(kgrid, str) and (kgrid == "gamma"):
         kpts_str = ['K_POINTS gamma\n']
@@ -214,17 +217,19 @@ def build_kpts_str(atoms, kspacing, kpts, koffset):
     else:
         kpts_str = ['K_POINTS automatic\n']
         kpts_str.append('{0[0]} {0[1]} {0[2]}  {1[0]:d} {1[1]:d} {1[2]:d}\n'
-                   ''.format(kgrid, koffset))
+                        ''.format(kgrid, koffset))
         kpts_str.append('\n')
     return kpts_str
 
+
 def build_atomic_positions_str(atoms, crystal_coordinates):
     '''
 
     '''
     import sys
     if 'species' not in atoms.arrays:
-        atoms.new_array('species', np.array(atoms.get_chemical_symbols(), dtype = 'U20'))
+        atoms.new_array('species', np.array(
+            atoms.get_chemical_symbols(), dtype='U20'))
     else:
         if len(atoms.arrays['species']) != len(atoms):
             sys.exit('Species is wrong, please check!')
@@ -263,7 +268,8 @@ def build_atomic_positions_str(atoms, crystal_coordinates):
             '{mask}\n'.format(species=species, coords=coords, mask=mask))
     return atomic_positions_str
 
-def write_neb_in(filename, images, climbing_images = [], path_data = {}, 
+
+def write_neb_in(filename, images, climbing_images=[], path_data={},
                  input_data={}, pseudopotentials=None,
                  kspacing=None, kpts=None, koffset=(0, 0, 0),
                  crystal_coordinates=False, **kwargs):
@@ -284,14 +290,14 @@ def write_neb_in(filename, images, climbing_images = [], path_data = {},
     """
     nebi = ['BEGIN\n']
     package_parameters = {
-            'PATH': {'string_method', 'restart_mode', 'nstep_path', 'num_of_images', 
-            'opt_scheme', 'CI_scheme', 'first_last_opt', 'minimum_image', 'temp_req', 
-            'ds', 'k_max', 'k_min', 'path_thr', 'use_masses', 'use_freezing', 
-            'lfcpopt', 'fcp_mu', 'fcp_tot_charge_first', 'fcp_tot_charge_last', },
-        }
+        'PATH': {'string_method', 'restart_mode', 'nstep_path', 'num_of_images',
+                 'opt_scheme', 'CI_scheme', 'first_last_opt', 'minimum_image', 'temp_req',
+                 'ds', 'k_max', 'k_min', 'path_thr', 'use_masses', 'use_freezing',
+                 'lfcpopt', 'fcp_mu', 'fcp_tot_charge_first', 'fcp_tot_charge_last', },
+    }
     path_str = ['\nBEGIN_PATH_INPUT\n']
     for section, parameters in package_parameters.items():
-        path_str.append('&%s\n '%section)
+        path_str.append('&%s\n ' % section)
         for key, value in path_data.items():
             if key in parameters:
                 if value is True:
@@ -304,18 +310,19 @@ def write_neb_in(filename, images, climbing_images = [], path_data = {},
     if climbing_images:
         path_str.append('CLIMBING_IMAGES\n')
         climbing_images_str = '   '
-        for x in climbing_images: climbing_images_str += ' %s'%x
+        for x in climbing_images:
+            climbing_images_str += ' %s' % x
         path_str.append(climbing_images_str)
         path_str.append('\n')
     path_str.append('END_PATH_INPUT\n')
     nebi.extend(path_str)
-    
+
     # BEGIN_ENGINE_INPUT
     engine_str = ['\nBEGIN_ENGINE_INPUT\n']
-    pwi = write_espresso_in(None, images[0], input_data, pseudopotentials, 
+    pwi = write_espresso_in(None, images[0], input_data, pseudopotentials,
                             kspacing, kpts, koffset, crystal_coordinates, **kwargs)
     engine_str.extend(pwi)
-    
+
     # POSITION
     atomic_positions_str = ['\nBEGIN_POSITIONS\n']
     for i in range(len(images)):
@@ -326,7 +333,8 @@ def write_neb_in(filename, images, climbing_images = [], path_data = {},
             atomic_positions_str.append('\nLAST_IMAGE\n')
         else:
             atomic_positions_str.append('\nINTERMEDIATE_IMAGE\n')
-        atomic_positions_str.extend(build_atomic_positions_str(atoms, crystal_coordinates))
+        atomic_positions_str.extend(
+            build_atomic_positions_str(atoms, crystal_coordinates))
     atomic_positions_str.append('END_POSITIONS\n')
     #
     engine_str.extend(atomic_positions_str)
@@ -348,11 +356,12 @@ def get_atomic_species(pwo):
                 nat = int(line.split()[-1])
             elif 'positions (alat units)' in line:
                 atomic_species = [at_line.split()[1]
-                    for at_line in lines[idx + 1:idx + 1 + nat]]
+                                  for at_line in lines[idx + 1:idx + 1 + nat]]
                 break
     return atomic_species
 
-def read_espresso_input(fileobj, neb = False):
+
+def read_espresso_input(fileobj, neb=False):
     """Parse a Quantum ESPRESSO input files, '.in', '.pwi'.
     """
     atoms = read_espresso_in(fileobj)
@@ -376,12 +385,13 @@ def read_espresso_input(fileobj, neb = False):
                 pseudopotentials[species[0]] = species[2]
         if line.strip().startswith('K_POINTS'):
             kpts = next(trimmed_lines)
-    # calc = Espresso(pseudopotentials=pseudopotentials, 
+    # calc = Espresso(pseudopotentials=pseudopotentials,
     #                 input_data = input_data,
     #                 kpts=kpts)
     return atoms, input_data, pseudopotentials, kpts, constraints
 
-def sort_qe_input(parameters, package = 'PW'):
+
+def sort_qe_input(parameters, package='PW'):
     """
     """
     from xespresso.input_parameters import qe_namespace, default_parameters
@@ -392,9 +402,11 @@ def sort_qe_input(parameters, package = 'PW'):
     sorted_parameters = copy.deepcopy(parameters)
     unuse_parameters = {}
     # section_names = ['CONTROL', 'SYSTEM', 'ELECTRONS', 'IONS', 'CELL', 'ATOMIC_SPECIES', 'K_POINTS', 'CELL_PARAMETERS', 'CONSTRAINTS', 'OCCUPATIONS', 'ATOMIC_VELECITIES', 'ATOMIC_FORCES']
-    section_names = ['CONTROL', 'SYSTEM', 'ELECTRONS', 'IONS', 'CELL', 'INPUT_NTYP']
+    section_names = ['CONTROL', 'SYSTEM',
+                     'ELECTRONS', 'IONS', 'CELL', 'INPUT_NTYP']
     for section in section_names:
-        if section not in sorted_parameters['input_data']: sorted_parameters['input_data'][section] = {}
+        if section not in sorted_parameters['input_data']:
+            sorted_parameters['input_data'][section] = {}
     for key, value in parameters.items():
         if key in ['pseudopotentials', 'kpts', 'kspacing', 'koffset', 'input_data', 'climbing_images', 'path_data', 'crystal_coordinates']:
             continue
@@ -405,7 +417,8 @@ def sort_qe_input(parameters, package = 'PW'):
                 flag = True
                 del sorted_parameters[key]
                 break
-            if section.upper() == 'INPUT_NTYP': continue
+            if section.upper() == 'INPUT_NTYP':
+                continue
             if key in pw_parameters[section]:
                 sorted_parameters['input_data'][section][key] = value
                 flag = True
@@ -418,7 +431,8 @@ def sort_qe_input(parameters, package = 'PW'):
     for key, value in input_data.items():
         flag = False
         if key.upper() in section_names:
-            sorted_parameters['input_data'][key.upper()] = sorted_parameters['input_data'].pop(key)
+            sorted_parameters['input_data'][key.upper(
+            )] = sorted_parameters['input_data'].pop(key)
             continue
         for section in section_names:
             if section.upper() == 'INPUT_NTYP':
@@ -433,7 +447,9 @@ def sort_qe_input(parameters, package = 'PW'):
             del sorted_parameters['input_data'][key]
     return sorted_parameters, unuse_parameters
     #
-def check_qe_input(input_parameters, package = 'PW'):
+
+
+def check_qe_input(input_parameters, package='PW'):
     from xespresso.input_parameters import qe_namespace, default_parameters
     from xespresso.utils import check_type
     pw_parameters = qe_namespace[package]
@@ -446,7 +462,8 @@ def check_qe_input(input_parameters, package = 'PW'):
             for key, value in parameters.items():
                 check_type(key, value, pw_parameters)
 
-def read_espresso_asei(fileobj, package = 'PW'):
+
+def read_espresso_asei(fileobj, package='PW'):
     """Parse Quantum ESPRESSO input parameters
     """
     with open(fileobj, 'rb') as fp:
@@ -457,12 +474,15 @@ def read_espresso_asei(fileobj, package = 'PW'):
     else:
         sorted_parameters = parameters
     return atoms, sorted_parameters
+
+
 def write_espresso_asei(fileobj, atoms, parameters):
     """save Quantum ESPRESSO input parameters
     """
     with open(fileobj, 'wb') as fp:
         pickle.dump([atoms, parameters], fp)
 
+
 def get_atomic_constraints(pwo, n_atoms):
     """
     Read constraints from QE output
@@ -488,6 +508,7 @@ def get_atomic_constraints(pwo, n_atoms):
     constraints = get_constraint(constraints)
     return constraints
 
+
 def get_constraint(constraint_idx):
     """
     Map constraints from QE output to FixAtoms or FixCartesian constraint
